@@ -84,7 +84,7 @@
 #define THREADWEAVER_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef THREADWEAVER_NO_DEPRECATED
-#  define THREADWEAVER_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56c00
+#  define THREADWEAVER_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56d00
 #endif
 #ifdef THREADWEAVER_NO_DEPRECATED_WARNINGS
 #  define THREADWEAVER_DEPRECATED_WARNINGS_SINCE 0
@@ -94,7 +94,7 @@
 #  ifdef THREADWEAVER_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define THREADWEAVER_DEPRECATED_WARNINGS_SINCE THREADWEAVER_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define THREADWEAVER_DEPRECATED_WARNINGS_SINCE 0x56c00
+#    define THREADWEAVER_DEPRECATED_WARNINGS_SINCE 0x56d00
 #  endif
 #endif
 
